==> nextcloud-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir o recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contrasinal da compartición remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Non admitido!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "Couldn't establish a federated share." : "Non foi posíbel estabelecer unha compartición federada",
    "Couldn't establish a federated share, maybe the password was wrong." : "Non foi posíbel estabelecer unha compartición federada, é probábel que o contrasinal sexa incorrecto.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Enviouse a solicitude dunha compartición federada, vostede recibirá unha notificación. Comprobe as súas notificacións.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Non foi posíbel estabelecer unha compartición federada, semella que o servidor  federar é antigo de máis (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Non está permitido enviar unha compartición de grupos federados  dende este servidor.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Produciuse un fallou na compartición de %1$s, este elemento xa está compartido con %2$s",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
    "File is already shared with %s" : "O ficheiro xa está a ser compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Produciuse un fallo ao compartir %1$s Non foi posíbel atopar %2$s, quizais haxa un problema de conexión co servidor  ou emprega un certificado autoasinado.",
    "Could not find share" : "Non foi posíbel atopar o recurso compartido",
    "Federated sharing" : "Compartición federada",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Vostede recibiu «%3$s» como un elemento compartido remoto de %4$s (%1$s) (de parte de %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vostede recibiu {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Vostede recibiu «%3$s» como un elemento compartido remoto de %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Vostede recibiu {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Comparte comigo a través do meu ID da nube federada do #Nextcloud , vexa %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparte comigo a través do meu ID da nube federada do #Nextcloud",
    "Sharing" : "Compartindo",
    "Federated file sharing" : "Compartir ficheiros en federación",
    "Provide federated file sharing across servers" : "Fornece a compartición federada de ficheiros entre servidores",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "Open documentation" : "Abrir a documentación",
    "Adjust how people can share between servers." : "Axustar como as persoas poden compartir entre servidores. ",
    "Allow users on this server to send shares to other servers" : "Permitirlle aos usuarios deste servidor enviar recursos compartidos a outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitirlle aos usuarios deste servidor recibir recursos compartidos doutros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permitirlle aos usuarios deste servidor enviar comparticións a grupos noutros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións de grupos dende outros servidores",
    "Search global and public address book for users" : "Buscar usuarios nos cadernos de enderezos globais e públicos",
    "Allow users to publish their data to a global and public address book" : "Permitirlle aos usuarios publicar os seus datos nun caderno de  enderezos global e público",
    "Federated Cloud" : "Nube federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode compartir con calquera persoa que empregue servidores Nextcloud, ou outro servidor ou  servizo compatíbel co Open Cloud Mesh (OCM)! Simplemente, introduza o seu ID de nube federada no diálogo de compartir. é algo como persona@cloud.exemplo.com",
    "Your Federated Cloud ID:" : "ID da súa nube federada:",
    "Share it so your friends can share files with you:" : "Compártao para que as súas amizades poidan compartir ficheiros con vostede:",
    "Add to your website" : "Engadir ao seu sitio web",
    "Share with me via Nextcloud" : "Comparte comigo a través do Nextcloud",
    "HTML Code:" : "Código HTML:",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Vostede recibiu «%3$s» como un elemento compartido remoto de %1$s  (de parte de %2$s)",
    "You received \"%3$s\" as a remote share from %1$s" : "Vostede recibiu «%3$s» como un elemento compartido remoto de %1$s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir o recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contrasinal da compartición remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Non admitido!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "Couldn't establish a federated share." : "Non foi posíbel estabelecer unha compartición federada",
    "Couldn't establish a federated share, maybe the password was wrong." : "Non foi posíbel estabelecer unha compartición federada, é probábel que o contrasinal sexa incorrecto.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Enviouse a solicitude dunha compartición federada, vostede recibirá unha notificación. Comprobe as súas notificacións.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Non foi posíbel estabelecer unha compartición federada, semella que o servidor  federar é antigo de máis (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Non está permitido enviar unha compartición de grupos federados  dende este servidor.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Produciuse un fallou na compartición de %1$s, este elemento xa está compartido con %2$s",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
    "File is already shared with %s" : "O ficheiro xa está a ser compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Produciuse un fallo ao compartir %1$s Non foi posíbel atopar %2$s, quizais haxa un problema de conexión co servidor  ou emprega un certificado autoasinado.",
    "Could not find share" : "Non foi posíbel atopar o recurso compartido",
    "Federated sharing" : "Compartición federada",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Vostede recibiu «%3$s» como un elemento compartido remoto de %4$s (%1$s) (de parte de %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vostede recibiu {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Vostede recibiu «%3$s» como un elemento compartido remoto de %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Vostede recibiu {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Comparte comigo a través do meu ID da nube federada do #Nextcloud , vexa %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparte comigo a través do meu ID da nube federada do #Nextcloud",
    "Sharing" : "Compartindo",
    "Federated file sharing" : "Compartir ficheiros en federación",
    "Provide federated file sharing across servers" : "Fornece a compartición federada de ficheiros entre servidores",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "Open documentation" : "Abrir a documentación",
    "Adjust how people can share between servers." : "Axustar como as persoas poden compartir entre servidores. ",
    "Allow users on this server to send shares to other servers. This option also allows WebDAV access to public shares" : "Permitirlle aos usuarios deste servidor enviar recursos compartidos a outros servidores. Esta opción tamén permite o acceso de WebDAV a recursos compartidos públicos",
    "Allow users on this server to receive shares from other servers" : "Permitirlle aos usuarios deste servidor recibir recursos compartidos doutros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permitirlle aos usuarios deste servidor enviar recursos compartidos a grupos noutros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións de grupos dende outros servidores",
    "Search global and public address book for users" : "Buscar usuarios nos cadernos de enderezos globais e públicos",
    "Allow users to publish their data to a global and public address book" : "Permitirlle aos usuarios publicar os seus datos nun caderno de  enderezos global e público",
    "Federated Cloud" : "Nube federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode compartir con calquera persoa que empregue servidores Nextcloud, ou outro servidor ou  servizo compatíbel co Open Cloud Mesh (OCM)! Simplemente, introduza o seu ID de nube federada no diálogo de compartir. É algo como persona@cloud.exemplo.com",
    "Your Federated Cloud ID:" : "ID da súa nube federada:",
    "Share it so your friends can share files with you:" : "Compártao para que as súas amizades poidan compartir ficheiros con vostede:",
    "Add to your website" : "Engadir ao seu sitio web",
    "Share with me via Nextcloud" : "Comparte comigo a través do Nextcloud",
    "HTML Code:" : "Código HTML:",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Vostede recibiu «%3$s» como un elemento compartido remoto de %1$s  (de parte de %2$s)",
    "You received \"%3$s\" as a remote share from %1$s" : "Vostede recibiu «%3$s» como un elemento compartido remoto de %1$s",
    "Allow users on this server to send shares to other servers" : "Permitirlle aos usuarios deste servidor enviar recursos compartidos a outros servidores"
},
"nplurals=2; plural=(n != 1);");
